#!/bin/bash

# NetCologne (Fritzbox) Shell-Utility 0.0.1, 28th August 2010, Jan Philipp
# Feel free. To Use. To Look. To improve. To contact. Mail is firstname at lastname minus online dot de

export NETCONNECT_BASE_URL="http://netconnect.box"
export DEBUG=0

export NETCONNECT_MODULE_OVERVIEW_SCRIPT="$NETCONNECT_BASE_URL/web.cgi?controller=Overview&action=IndexOverview&id=0"
export NETCONNECT_MODULE_INTERNET_SCRIPT="$NETCONNECT_BASE_URL/web.cgi?controller=Internet&action=Index"
export NETCONNECT_MODULE_INTERNET_STRT_PPPOE_SCRIPT="$NETCONNECT_BASE_URL/web.cgi?controller=Internet&action=StartPppoe&id=0"
export NETCONNECT_MODULE_INTERNET_STOP_PPPOE_SCRIPT="$NETCONNECT_BASE_URL/web.cgi?controller=Internet&action=StopPppoe&id=0"

# Local settings
export TEMP_FILE="/tmp/netconnect-download"
export TEMP_COOKIES="/tmp/netconnect-cookies"
export I_HAVE_A_SESSION=0

function  printHelp() {
	echo "NetCologne (Fritzbox) Shell-Utility 0.0.1, 28th August 2010, Jan Philipp"
	echo 
	echo "Usage: $0 [COMMAND]"
	echo 
	echo "Following commands are available:"
	echo "  connect             performs a connect (PPPoE device)"
	echo "  disconnect          performs a disconnect (PPPoE device)"
	echo "  reconnect           performs a disconnect and a connect (PPPoE device)"
	echo "  uptime              shows the current uptime"
	echo "  ipaddr              shows the current external ip address"
	echo 
}

# Because the web page uses a cookkie and session check we have to visit the
# frontpage getting the cookie before looking for the uptime in the second request.
function getSession() {
  if [ $DEBUG -eq 1 ]
  then
    echo "Asking for a new session..."
  fi
  wget -q --cookies=on --keep-session-cookies --save-cookies="$TEMP_COOKIES" -O"$TEMP_FILE" "$NETCONNECT_MODULE_OVERVIEW_SCRIPT"
  export I_HAVE_A_SESSION=1
  if [ $DEBUG -eq 1 ]
  then
    echo "Session created."
  fi
}

function releaseTempRessources() {
  rm "$TEMP_FILE" "$TEMP_COOKIES"
  export I_HAVE_A_SESSION=0
  if [ $DEBUG -eq 1 ]
  then 
    echo "Ressources destroyed."
  fi
}

function getUptime() {
  if [ $I_HAVE_A_SESSION -ne 1 ]
  then
    if [ $DEBUG -eq 1 ]
    then
      echo "This operation requires a session."
    fi
    getSession
  fi
  
  if [ $DEBUG -eq 1 ]
  then
    echo "Retrieving uptime value..."
  fi
  wget -q --referer="$NETCONNECT_MODULE_OVERVIEW_SCRIPT" --cookies=on --load-cookies="$TEMP_COOKIES" --keep-session-cookies --save-cookies="$TEMP_COOKIES" -O"$TEMP_FILE" "$NETCONNECT_MODULE_INTERNET_SCRIPT"
  
  export LAST_RESULT=`cat "$TEMP_FILE" | grep "idPOnlineTime" | awk -F: '{split($1,result,",")} END{printf "%02d:%02d:%02d\n", result[2], result[3],result[4]}'`
}

function getExternalIpAddr() {
  if [ $I_HAVE_A_SESSION -ne 1 ]
  then
    if [ $DEBUG -eq 1 ]
    then
      echo "This operation requires a session."
    fi
    getSession
  fi
  
  if [ $DEBUG -eq 1 ]
  then
    echo "Retrieving ip addr value..."
  fi
  wget -q --referer="$NETCONNECT_MODULE_OVERVIEW_SCRIPT" --cookies=on --load-cookies="$TEMP_COOKIES" --keep-session-cookies --save-cookies="$TEMP_COOKIES" -O"$TEMP_FILE" "$NETCONNECT_MODULE_INTERNET_SCRIPT"
  
  export LAST_RESULT=`cat "$TEMP_FILE" | grep -B5 "Netz&#252;bergang" | grep -m1 ""`
}

function startPPPoE() {
  if [ $I_HAVE_A_SESSION -ne 1 ]
  then
    if [ $DEBUG -eq 1 ]
    then
      echo "This operation requires a session."
    fi
    getSession
  fi

  if [ $DEBUG -eq 1 ]
  then
    echo "Starting PPPoE device..."
  fi
  wget -q --referer="$NETCONNECT_MODULE_INTERNET_SCRIPT" --cookies=on --load-cookies="$TEMP_COOKIES" --keep-session-cookies --save-cookies="$TEMP_COOKIES" -O"$TEMP_FILE" "$NETCONNECT_MODULE_INTERNET_STRT_PPPOE_SCRIPT"

  export LAST_RESULT=0
}


function stopPPPoE() {
  if [ $I_HAVE_A_SESSION -ne 1 ]
  then
    if [ $DEBUG -eq 1 ]
    then
      echo "This operation requires a session."
    fi
    getSession
  fi

  if [ $DEBUG -eq 1 ]
  then
    echo "Stopping PPPoE device..."
  fi
  wget -q --referer="$NETCONNECT_MODULE_INTERNET_SCRIPT" --cookies=on --load-cookies="$TEMP_COOKIES" --keep-session-cookies --save-cookies="$TEMP_COOKIES" -O"$TEMP_FILE" "$NETCONNECT_MODULE_INTERNET_STOP_PPPOE_SCRIPT"

  export LAST_RESULT=0
}

#stopPPPoE
#startPPPoE
#releaseTempRessources
#echo $LAST_RESULT

if [[ $1 == "uptime" ]]
then
  getUptime
  echo "The current uptime is: $LAST_RESULT"
  exit 0
fi

if [[ $1 == "ipaddr" ]]
then
  getExternalIpAddr
  echo "The current external ip address is: $LAST_RESULT"
  exit 0
fi

if [[ $1 == "connect" ]]
then
  startPPPoE
  getUptime
  echo "The current uptime is: $LAST_RESULT"
  exit 0
fi

if [[ $1 == "disconnect" ]]
then
  stopPPPoE
  #echo "The current uptime is: $LAST_RESULT"
  exit 0
fi

if [[ $1 == "reconnect" ]]
then
  stopPPPoE
  startPPPoE
  getUptime
  echo "The current uptime is: $LAST_RESULT"
  exit 0
fi

# Okay, display help
printHelp

exit 0
